Learn R Programming

rbokeh (version 0.4.2)

widget2png: Make a static png file for an htmlwidget

Description

Make a static png file for an htmlwidget

Usage

widget2png(p, file, timeout = 500)

Arguments

p
htmlwidget object
file
where to save png file
timeout
plot render timeout in milliseconds (see details)

Details

This uses phantomjs (http://phantomjs.org) to render your htmlwidget in a headless browser and take a screenshot of it, creating a static output. This assumes that phantomjs has been installed on your machine and is available as a system call. For plots that take longer to load and render, you may need to increase the value of timeout. Note that this function is experimental.

Examples

Run this code

figure(tools = NULL) %>%
  ly_points(1:10) %>%
  widget2png("/tmp/test.png")

Run the code above in your browser using DataLab