ly_contour(fig, z, x = seq(0, 1, length.out = nrow(z)), y = seq(0, 1, length.out = ncol(z)), nlevels = 10, levels = pretty(range(z, na.rm = TRUE), nlevels), color = "black", alpha = 1, width = 1, type = 1, lname = NULL, lgroup = NULL, visible = TRUE, ...)image are measured (see contourLines)contourLines)lty property in par or an array of integer pixel distances that describe the on-off pattern of dashing to use
line_join |
| how path segments should be joined together 'miter' 'round' 'bevel' |
line_cap |
| how path segments should be terminated 'butt' 'round' 'square' |
line_dash |
an integer between 1 and 6 matching the lty property in par or an array of integer pixel distances that describe the on-off pattern of dashing to use |
ly_abline,
ly_annular_wedge, ly_annulus,
ly_arc, ly_bar,
ly_bezier, ly_boxplot,
ly_crect, ly_curve,
ly_density, ly_hist,
ly_image_url, ly_image,
ly_lines, ly_map,
ly_multi_line, ly_oval,
ly_patch, ly_points,
ly_polygons, ly_quadratic,
ly_quantile, ly_ray,
ly_rect, ly_segments,
ly_text, ly_wedge
p <- figure(xlim = c(0, 1), ylim = c(0, 1), title = "Volcano") %>%
ly_image(volcano) %>%
ly_contour(volcano)
p
Run the code above in your browser using DataLab