ly_ray: Add a "ray" layer to a Bokeh figure
Description
Draws line segments starting at the given coordinate and extending the given length at the given angle.
Usage
ly_ray(fig, x, y = NULL, data = figure_data(fig), length = NULL, angle = 0, color = "black", type = 1, width = 1, alpha = NULL, legend = NULL, lname = NULL, lgroup = NULL, visible = TRUE, ...)
Arguments
x
values or field name of center x coordinates
y
values or field name of center y coordinates
data
an optional data frame, providing the source for inputs x, y, and other glyph properties
length
values or field name of ray lengths in screen units
angle
values or field name of ray angles
color
color to use to stroke lines with - a hex code (with no alpha) or any of the 147 named CSS colors, e.g 'green', 'indigo'
type
an integer between 1 and 6 matching the lty property in par or an array of integer pixel distances that describe the on-off pattern of dashing to use width
stroke width in units of pixels
alpha
transparency value for the line between 0 (transparent) and 1 (opaque)
legend
either a logical specifying not to plot a legend for this layer (FALSE) or a string indicating the name of the legend entry for this layer (note that when mapping plot attributes to variables in data, a legend is automatically created and does not need to be specified - see "Mapped plot attributes and legends" below)
visible
should the layer be visible?
...
additional parameters for fine control over line properties (see "Additional parameters" below)
Mapped plot attributes and legends
When specifying an input data frame for a layer through the data argument, columns of data can be used to specify various plot attributes such as color, etc. For example, with ly_points(..., data = iris, color = Species), the Species variable is used to determine how to color the points. Here, Species is "mapped" to the color attribute. Both continuous and categorical variables can be mapped. In the case of continuous variables, the range is cut into slices and attributes are applied to each interval. The mapping from the values of the variable to the actual plot attributes is determined based on the theme.Additional parameters
line_join |
| how path segments should be joined together 'miter' 'round' 'bevel' |
line_cap |
| how path segments should be terminated 'butt' 'round' 'square' |
line_dash |
an integer between 1 and 6 matching the lty property in par or an array of integer pixel distances that describe the on-off pattern of dashing to use |
See Also
Other layer functions: ly_abline,
ly_annular_wedge, ly_annulus,
ly_arc, ly_bar,
ly_bezier, ly_boxplot,
ly_contour, ly_crect,
ly_curve, ly_density,
ly_hist, ly_image_url,
ly_image, ly_lines,
ly_map, ly_multi_line,
ly_oval, ly_patch,
ly_points, ly_polygons,
ly_quadratic, ly_quantile,
ly_rect, ly_segments,
ly_text, ly_wedge